@@ -1,3 +1,6 @@
+# Copyright 2021 VMware, Inc.
+# SPDX-License-Identifier: Apache License 2.0
+
 """ Health Monitor Conversion Goes here """
 import logging
 from avi.migrationtools.ace_converter.ace_constants import\
@@ -67,6 +70,8 @@ class MonitorConverter(object):
                 # for url
                 if health_monitor.get('method', []) and health_monitor.get('url', []):
                     request_url = "{} {}".format(health_monitor['method'], health_monitor['url'])
+                elif health_monitor.get('header-value', []):
+                    request_url = "HEAD Host:{}".format(str(health_monitor['header-value']).replace('"', ''))
                 else:
                     request_url = health_monitor.get('url', [])
 
@@ -90,17 +95,20 @@ class MonitorConverter(object):
                 if health_monitor.get('regex', []):
                     response_code.append('HTTP_ANY')
                 health_monitor_type = 'http_monitor'
+                server_response_data = health_monitor.get('status1', [])
                 if health_monitor['type'] == 'https':
                     health_monitor_type = 'https_monitor'
 
                 extra_details = {
                                     health_monitor_type: {
                                         "maintenance_response": "",
-                                        "http_request": request_url,
-                                        "http_response_code": response_code,
-                                        "http_response": ""
+                                        "client_request_data": request_url,
+                                        "response_data": response_code,
+                                        "server_response_data": server_response_data,
+                                        "description": "",
                                     }
                                 }
+
                 monitor.update(extra_details)
 
             # Excel Sheet updating
