@@ -520,7 +520,7 @@ class AviAnsibleConverterMigration(AviAnsibleConverterBase):
                                      % self.outdir
         # Get the reference object list for not_in_use tag.
         inuse_list = []
-        if not self.not_in_use:
+        if 'VirtualService' in self.avi_cfg and not self.not_in_use:
             inuse_list = filter_for_vs(self.avi_cfg)
         ad = deepcopy(ansible_dict)
         generate_traffic_dict = deepcopy(ansible_dict)
@@ -612,7 +612,7 @@ if __name__ == '__main__':
     parser.add_argument(
         '--controller_version',
         help='Target Avi controller version',
-        default='18.2.6')
+        default='17.2.1')
     args = parser.parse_args()
 
     with open(args.config_file, "r+") as f:
