@@ -284,29 +284,18 @@ class MonitorConverter(object):
                     # Removed \\ from response.
                     if '\\' in response:
                         response = response.replace('\\', '"')
-                # TODO: Remove this after all the clients are moved to 
-                # 17 version and above
-                if parse_version(self.controller_version) >= parse_version(
-                        '17.1'):
-                    avi_monitor["https_monitor"] = {
-                        "http_request": send,
-                        "http_response_code": resp_code,
-                        "ssl_attributes": ssl_attributes,
-                        "http_response": response
-                    }
-                if parse_version(self.controller_version) >= parse_version(
-                        '17.1.6'):
-                    custom_header = ns_monitor.get('customHeaders')
-                    if custom_header:
-                        avi_monitor['https_monitor'].update({
-                            'exact_http_request': True,
-                            'http_request': (send + ' HTTP/1.0' + "\r\n" +
-                                            custom_header + "\r\n").replace('"',
-                                            '').replace('\\r\\n', '\r\n') if
-                                            send else ('HTTP/1.0' + "\r\n" +
-                                            custom_header + "\r\n").replace('"',
-                                            '').replace('\\r\\n', '\r\n')
-                        })
+
+                custom_header = ns_monitor.get('customHeaders')
+                if custom_header:
+                    avi_monitor['https_monitor'].update({
+                        'exact_http_request': True,
+                        'http_request': (send + ' HTTP/1.0' + "\r\n" +
+                                        custom_header + "\r\n").replace('"',
+                                        '').replace('\\r\\n', '\r\n') if
+                                        send else ('HTTP/1.0' + "\r\n" +
+                                        custom_header + "\r\n").replace('"',
+                                        '').replace('\\r\\n', '\r\n')
+                    })
             elif mon_type == 'HTTP':
                 avi_monitor["type"] = "HEALTH_MONITOR_HTTP"
                 send = ns_monitor.get('httpRequest', None)
