@@ -6,7 +6,6 @@ import os
 import time
 from avi.sdk.avi_api import ApiSession
 import requests
-from requests import ConnectionError
 
 def verify_controller_is_up(controller_ip, username, password):
     """""
@@ -91,22 +90,14 @@ def wait_until_node_ready(controller_ip, interval=120, timeout=3000):
     """
     cluster_up_states = ["CLUSTER_UP_HA_ACTIVE", "CLUSTER_UP_NO_HA"]
     iters = int(timeout / interval)
-    retries = 8
-    retry = 0
     for count in range(0, iters):
-        try:
-            data = requests.get('https://{ip}/api/cluster/runtime'.format(ip=controller_ip), verify=False)
-            if type(data) != dict and data.status_code == 200:
-                response_content = data.content.decode() if type(data.content) == bytes else data.content
-                data = json.loads (response_content)
-                if data['cluster_state']['state'] in cluster_up_states:
-                    print("node is active")
-                    break
-            time.sleep(interval)
-        except ConnectionError as err:
-            retry += 1
-            if retry >= retries:
-                raise Exception('Connection break : %s' % err)
-            continue
+        data = requests.get('https://{ip}/api/cluster/runtime'.format(ip=controller_ip), verify=False)
+        if type(data) != dict and data.status_code == 200:
+            response_content = data.content.decode() if type(data.content) == bytes else data.content
+            data = json.loads (response_content)
+            if data['cluster_state']['state'] in cluster_up_states:
+                print("node is active")
+                break
+        time.sleep (interval)
     else:
         raise Exception("Node is not in up state after timeout %s" % timeout)
