@@ -1,3 +1,6 @@
+# Copyright 2021 VMware, Inc.
+# SPDX-License-Identifier: Apache License 2.0
+
 import json
 from avi.sdk.avi_api import ApiSession
 
@@ -26,8 +29,7 @@ def create_cloud(controller_ip, username, password, cloud_name):
     path = "/cloud?include_name"
     rsp1 = session.post (path, data=json_data)
     print(rsp1)
-    response_content = rsp1.content.decode() if type(rsp1.content) == bytes else rsp1.content
-    return json.loads (response_content)
+    return json.loads (rsp1.content)
 
 
 def create_segroup(controller_ip, username, password, segroup_name):
