@@ -23,13 +23,16 @@ mg_util = MigrationUtil()
 path_key_map = mg_util.get_path_key_map()
 
 warning_list = []
+skip_ref_object_list = ['cloud_ref', 'tenant_ref', 'se_group_ref']
 
 
-def filter_for_vs(avi_config, vs_names):
+def filter_for_vs(avi_config, vs_names, prefix=None, skip_ref_objects=skip_ref_object_list):
     """
     Filters vs and its references from full configuration
     :param avi_config: full configuration
     :param vs_names: comma separated vs names to filter
+    :param prefix: prefix for an object
+    :param skip_ref_objects: comma separated names of objects ref to be skipped
     :return: Filtered config dict
     """
     new_config = dict()
@@ -41,6 +44,9 @@ def filter_for_vs(avi_config, vs_names):
         virtual_services = vs_names
 
     for vs_name in virtual_services:
+        if prefix:
+            if not vs_name.startswith(prefix):
+                vs_name = prefix+"-"+vs_name
         vs = [vs for vs in avi_config['VirtualService']
               if vs['name'] == vs_name]
         if not vs:
@@ -50,7 +56,7 @@ def filter_for_vs(avi_config, vs_names):
         vs = vs[0]
         new_config['VirtualService'].append(vs)
         print('%s(VirtualService)' % vs_name)
-        find_and_add_objects(vs, avi_config, new_config, depth=0)
+        find_and_add_objects(vs, avi_config, new_config, depth=0, skip_ref_objects=skip_ref_objects)
 
     for warn in warning_list:
         print("\033[1;33;50m  %s   \033[0m" %(warn))
@@ -58,7 +64,7 @@ def filter_for_vs(avi_config, vs_names):
     return new_config
 
 
-def search_obj(entity, name, new_config, avi_config, depth):
+def search_obj(entity, name, new_config, avi_config, depth, skip_ref_objects=skip_ref_object_list):
     """
     Method to search referenced object
     :param entity: object type
@@ -66,6 +72,7 @@ def search_obj(entity, name, new_config, avi_config, depth):
     :param new_config: filtered config
     :param avi_config: full config
     :param depth: Recursion depth to determine level in the vs reference tree
+    :param skip_ref_objects: comma separated names of objects ref to be skipped
     """
 
     avi_conf_key = path_key_map[entity]
@@ -73,7 +80,7 @@ def search_obj(entity, name, new_config, avi_config, depth):
     found_obj = [obj for obj in found_obj_list if obj['name'] == name]
     if found_obj:
         found_obj = found_obj[0]
-        print(' | '*depth + '|- %s(%s)' % (name, path_key_map[entity]))
+        print('| '*depth + '|- %s(%s)' % (name, path_key_map[entity]))
     elif entity in ['applicationprofile', 'networkprofile', 'healthmonitor',
                     'sslkeyandcertificate', 'sslprofile']:
         if str.startswith(str(name), 'System-'):
@@ -90,19 +97,20 @@ def search_obj(entity, name, new_config, avi_config, depth):
     else:
         new_config[avi_conf_key] = [found_obj]
     depth += 1
-    find_and_add_objects(found_obj, avi_config, new_config, depth)
+    find_and_add_objects(found_obj, avi_config, new_config, depth, skip_ref_objects=skip_ref_objects)
 
 
-def find_and_add_objects(obj_dict, avi_config, new_config, depth):
+def find_and_add_objects(obj_dict, avi_config, new_config, depth, skip_ref_objects=skip_ref_object_list):
     """
     Method to iterate in one object find references and add those to output
     :param obj_dict: Object to be iterated over
     :param avi_config: Full config
     :param new_config: Filtered config
     :param depth: Recursion depth to determine level in the vs reference tree
+    :param skip_ref_objects: comma separated names of objects ref to be skipped
     """
     for key in obj_dict:
-        if (key.endswith('ref') and key not in ['cloud_ref', 'tenant_ref', 'se_group_ref']) \
+        if (key.endswith('ref') and key not in skip_ref_objects) \
                 or key == 'ssl_profile_name':
             if not obj_dict[key]:
                 continue
@@ -113,11 +121,13 @@ def find_and_add_objects(obj_dict, avi_config, new_config, depth):
                 entity, name = mg_util.get_name_and_entity(ref)
                 search_obj(entity, name, new_config, avi_config, depth)
         elif isinstance(obj_dict[key], dict):
-            find_and_add_objects(obj_dict[key], avi_config, new_config, depth)
+            find_and_add_objects(obj_dict[key], avi_config, new_config, depth,
+                                 skip_ref_objects=skip_ref_objects)
         elif obj_dict[key] and isinstance(obj_dict[key], list) \
                 and isinstance(obj_dict[key][0], dict):
             for member in obj_dict[key]:
-                find_and_add_objects(member, avi_config, new_config, depth)
+                find_and_add_objects(member, avi_config, new_config, depth,
+                                     skip_ref_objects=skip_ref_objects)
     return
 
 
@@ -146,11 +156,21 @@ if __name__ == '__main__':
     parser.add_argument('-p', '--print_only', action='store_true',
                         help='Only prints tree of object references and wont '
                              'generate the filter output json')
+    parser.add_argument('-s', '--skip_ref_objects',
+                        help='comma separated names of object refs to be skipped in migration. '
+                             'Choices: cloud_ref,tenant_ref,se_group_ref')
 
     args = parser.parse_args()
+
+    if not args.skip_ref_objects:
+        args.skip_ref_objects = skip_ref_object_list
+    else:
+        if type(args.skip_ref_objects) == str:
+            args.skip_ref_objects = args.skip_ref_objects.split(',')
+
     avi_config_file = open(args.avi_config_file)
     old_avi_config = json.loads(avi_config_file.read())
-    new_avi_config = filter_for_vs(old_avi_config, args.vs_names)
+    new_avi_config = filter_for_vs(old_avi_config, args.vs_names, skip_ref_objects=args.skip_ref_objects)
 
     if not args.print_only:
         output_dir = os.path.normpath(args.output_file_path)
